﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;

namespace Hardcodet.Wpf
{
  /// <summary>
  /// Hosts the attached rule property for the sample.
  /// </summary>
  public class Editors
  {

    #region TextRule

    /// <summary>
    /// TextRule Attached Dependency Property
    /// </summary>
    public static readonly DependencyProperty TextRuleProperty =
        DependencyProperty.RegisterAttached("TextRule", typeof(ValidationRule), typeof(Nullable),
            new FrameworkPropertyMetadata(null, OnTextRuleChanged));


    /// <summary>
    /// Gets the TextRule property.  This dependency property 
    /// indicates ....
    /// </summary>
    public static ValidationRule GetTextRule(DependencyObject d)
    {
      return (ValidationRule)d.GetValue(TextRuleProperty);
    }

    /// <summary>
    /// Sets the TextRule property.  This dependency property 
    /// indicates ....
    /// </summary>
    public static void SetTextRule(DependencyObject d, ValidationRule value)
    {
      d.SetValue(TextRuleProperty, value);
    }

    /// <summary>
    /// Handles changes to the TextRule property.
    /// </summary>
    private static void OnTextRuleChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
    {
      var textBox = d as TextBox;
      if (textBox == null) return;

      //nice pattern - thx to Josh Smith (http://joshsmithonwpf.wordpress.com/)
      if (!textBox.IsInitialized)
      {
        EventHandler callback = null;
        callback = delegate
        {
          textBox.Initialized -= callback;
          OnTextRuleChanged(d, e);
        };

        textBox.Initialized += callback;
        return;
      }

      var exp = textBox.GetBindingExpression(TextBox.TextProperty);
      if (exp == null) return;

      //add the rule to the binding's validation rules
      exp.ParentBinding.ValidationRules.Add((ValidationRule)e.NewValue);
    }

    #endregion

  }
}
