﻿using System;
using System.ComponentModel;

namespace Hardcodet.Wpf.Model
{
  /// <summary>
  /// Simple sample model class
  /// </summary>
  public class Person : INotifyPropertyChanged, IDataErrorInfo
  {
    #region Age

    /// <summary>
    /// The age.
    /// </summary>
    private int age = -1;


    /// <summary>
    /// The age.
    /// </summary>
    public int Age
    {
      get { return age; }
      set
      {
        age = value;
        OnPropertyChanged("Age");
      }
    }

    #endregion

    #region FirstName

    /// <summary>
    /// Description
    /// </summary>
    private string firstName = String.Empty;


    /// <summary>
    /// Description
    /// </summary>
    public string FirstName
    {
      get { return firstName; }
      set
      {
        firstName = value;
        OnPropertyChanged("FirstName");
      }
    }

    #endregion

    #region INotifyPropertyChanged event

    ///<summary>
    ///Occurs when a property value changes.
    ///</summary>
    public event PropertyChangedEventHandler PropertyChanged;


    /// <summary>
    /// Raises the <see cref="PropertyChanged"/> event for
    /// a given property.
    /// </summary>
    /// <param name="propertyName">The name of the changed property.</param>
    protected void OnPropertyChanged(string propertyName)
    {
      if (PropertyChanged != null)
      {
        PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
      }
    }

    #endregion



    public string this[string columnName]
    {
      get
      {
        if (columnName == "Age" && (Age < 1 || Age > 130))
        {
          return String.Format("Age {0} is invalid - specify an age between 1 and 130.", Age);
        }

        return "";
      }
    }


    public string Error
    {
      get { return null; }
    }
  }
}