﻿using System;
using System.Globalization;
using System.Windows.Controls;

namespace Hardcodet.Wpf.ValidationRules
{
  public class MinNumericRule : NumericRule
  {
    /// <summary>
    /// A minimum value required to satisfy the
    /// rule.
    /// </summary>
    public int MinValue { get; set; }  


    /// <summary>
    /// Overrides the base rule in order to check against the <see cref="MinValue"/>,
    /// if specified.
    /// </summary>
    public override ValidationResult Validate(object value, CultureInfo cultureInfo)
    {
      //delegate validation to base class
      var status = base.Validate(value, cultureInfo);
      if (!status.IsValid) return status;

      //check min value
      int result = int.Parse(value.ToString(), NumberStyles.Number, cultureInfo.NumberFormat);
      if (result < MinValue)
      {
        string msg = String.Format("Minimum override: Age must be at least {0}", MinValue);
        return new ValidationResult(false, msg);
      }

      //if validation is ok, just return the base result
      return status;
    }
  }
}